assertInputPresent abstract method

FutureOr<Browser> assertInputPresent(
  1. String name
)
inherited

Asserts that an input field with the specified name is present.

name is the name attribute of the input field.

Implementation

FutureOr<Browser> assertInputPresent(String name);