assertRadioNotSelected abstract method

FutureOr<Browser> assertRadioNotSelected(
  1. String field,
  2. String value
)
inherited

Asserts that a radio button with the specified name and value is not selected.

field is the name of the radio button group. value is the value of the radio button that should not be selected.

Implementation

FutureOr<Browser> assertRadioNotSelected(String field, String value);