assertSeeIn abstract method

FutureOr<Browser> assertSeeIn(
  1. String selector,
  2. String text
)
inherited

Asserts that the specified element contains the given text.

selector is the CSS selector for the element. text is the text to find within the element.

Implementation

FutureOr<Browser> assertSeeIn(String selector, String text);