assertNotSelected abstract method
Asserts that an option with the specified value is not selected in a select element.
field is a CSS selector for the select element.
value is the value of the option that should not be selected.
Implementation
FutureOr<Browser> assertNotSelected(String field, String value);