assertSeeIn abstract method
Asserts that the specified element contains the given text.
selector is the CSS selector for the element.
text is the text to find within the element.
Implementation
FutureOr<Browser> assertSeeIn(String selector, String text);